@@ -202,3 +202,7 @@ NoteContainer if there are notes playing."""
 				playing.append([x[0], x[1] - 1])
 
 		self.playing = playing
+
+	def stop(self):
+		for x in range(128):
+			fluidsynth.stop_Note(x, self.last_chan)
