@@ -146,6 +146,8 @@ class Sequencer:
 				i += 1
 		self.block.stop()
 		if not self.get_next_block():
+			for i in self.instruments:
+				i.stop()
 			self.output_midi()
 		else:
 			self.play()
